@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2004  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2005  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.h,v 1.46 2005/01/13 22:37:58 holtmann Exp $
+ *  $Id: hci.h,v 1.49 2005/01/29 03:24:48 holtmann Exp $
  */
 
 #ifndef __HCI_H
@@ -762,6 +762,7 @@ typedef struct {
 	uint8_t		status;
 	uint8_t		features[8];
 } __attribute__ ((packed)) read_local_features_rp;
+#define READ_LOCAL_FEATURES_RP_SIZE 9
 
 #define OCF_READ_BUFFER_SIZE		0x0005
 typedef struct {
@@ -771,12 +772,14 @@ typedef struct {
 	uint16_t	acl_max_pkt;
 	uint16_t	sco_max_pkt;
 } __attribute__ ((packed)) read_buffer_size_rp;
+#define READ_BUFFER_SIZE_RP_SIZE 8
 
 #define OCF_READ_BD_ADDR		0x0009
 typedef struct {
 	uint8_t		status;
 	bdaddr_t	bdaddr;
 } __attribute__ ((packed)) read_bd_addr_rp;
+#define READ_BD_ADDR_RP_SIZE 7
 
 /* Status params */
 #define OGF_STATUS_PARAM	0x05
@@ -821,6 +824,20 @@ typedef struct {
 } __attribute__ ((packed)) read_afh_map_rp;
 #define READ_AFH_MAP_RP_SIZE 14
 
+#define OCF_READ_CLOCK			0x0007
+typedef struct {
+	uint16_t	handle;
+	uint8_t		which_clock;
+} __attribute__ ((packed)) read_clock_cp;
+#define READ_CLOCK_CP_SIZE 3
+typedef struct {
+	uint8_t		status;
+	uint16_t	handle;
+	uint32_t	clock;
+	uint16_t	accuracy;
+} __attribute__ ((packed)) read_clock_rp;
+#define READ_CLOCK_RP_SIZE 9
+
 /* Testing commands */
 #define OGF_TESTING_CMD		0x3e
 
