@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2004  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2005  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci_lib.h,v 1.37 2005/01/13 22:57:36 holtmann Exp $
+ *  $Id: hci_lib.h,v 1.41 2005/01/29 03:24:48 holtmann Exp $
  */
 
 #ifndef __HCI_LIB_H
@@ -73,6 +73,8 @@ int hci_read_remote_features(int dd, uint16_t handle, uint8_t *features, int to)
 int hci_read_remote_version(int dd, uint16_t handle, struct hci_version *ver, int to);
 int hci_read_clock_offset(int dd, uint16_t handle, uint16_t *clkoffset, int to);
 int hci_read_local_version(int dd, struct hci_version *ver, int to);
+int hci_read_local_features(int dd, uint8_t *features, int to);
+int hci_read_bd_addr(int dd, bdaddr_t *bdaddr, int to);
 int hci_read_class_of_dev(int dd, uint8_t *cls, int to);
 int hci_write_class_of_dev(int dd, uint32_t cls, int to);
 int hci_read_voice_setting(int dd, uint16_t *vs, int to);
@@ -96,6 +98,10 @@ int hci_set_afh_classification(int dd, uint8_t *map, int to);
 int hci_read_link_quality(int dd, uint16_t handle, uint8_t *link_quality, int to);
 int hci_read_rssi(int dd, uint16_t handle, int8_t *rssi, int to);
 int hci_read_afh_map(int dd, uint16_t handle, uint8_t *mode, uint8_t *map, int to);
+int hci_read_clock(int dd, uint16_t handle, uint8_t which, uint32_t *clock, uint16_t *accuracy, int to);
+
+int hci_local_name(int dd, int len, char *name, int to);
+int hci_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to);
 
 int hci_for_each_dev(int flag, int(*func)(int s, int dev_id, long arg), long arg);
 int hci_get_route(bdaddr_t *bdaddr);
