@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2004  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2005  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.c,v 1.57 2005/01/13 22:57:37 holtmann Exp $
+ *  $Id: hci.c,v 1.62 2005/01/29 23:30:04 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -453,51 +453,58 @@ int hci_for_each_dev(int flag, int (*func)(int s, int dev_id, long arg), long ar
 	struct hci_dev_list_req *dl;
 	struct hci_dev_req *dr;
 	int dev_id = -1;
-	int s, i;
+	int i, sk;
 
-	s = socket(AF_BLUETOOTH, SOCK_RAW, BTPROTO_HCI);
-	if (s < 0)
+	sk = socket(AF_BLUETOOTH, SOCK_RAW, BTPROTO_HCI);
+	if (sk < 0)
 		return -1;
 
 	dl = malloc(HCI_MAX_DEV * sizeof(*dr) + sizeof(*dl));
 	if (!dl) {
-		close(s);
+		close(sk);
 		return -1;
 	}
 
 	dl->dev_num = HCI_MAX_DEV;
 	dr = dl->dev_req;
 
-	if (ioctl(s, HCIGETDEVLIST, (void *)dl))
+	if (ioctl(sk, HCIGETDEVLIST, (void *) dl))
 		goto done;
 
-	for (i=0; i < dl->dev_num; i++, dr++) {
+	for (i = 0; i < dl->dev_num; i++, dr++) {
 		if (hci_test_bit(flag, &dr->dev_opt))
-			if (!func || func(s, dr->dev_id, arg)) {
+			if (!func || func(sk, dr->dev_id, arg)) {
 				dev_id = dr->dev_id;
 				break;
 			}
 	}
 
 done:
-	close(s);
+	close(sk);
 	free(dl);
 	return dev_id;
 }
 
-static int __other_bdaddr(int s, int dev_id, long arg)
+static int __other_bdaddr(int sk, int dev_id, long arg)
 {
-	struct hci_dev_info di = {dev_id: dev_id};
-	if (ioctl(s, HCIGETDEVINFO, (void *) &di))
+	struct hci_dev_info di = { dev_id: dev_id };
+
+	if (ioctl(sk, HCIGETDEVINFO, (void *) &di))
 		return 0;
+
+	if (hci_test_bit(HCI_RAW, &di.flags))
+		return 0;
+
 	return bacmp((bdaddr_t *) arg, &di.bdaddr);
 }
 
-static int __same_bdaddr(int s, int dev_id, long arg)
+static int __same_bdaddr(int sk, int dev_id, long arg)
 {
-	struct hci_dev_info di = {dev_id: dev_id};
-	if (ioctl(s, HCIGETDEVINFO, (void *) &di))
+	struct hci_dev_info di = { dev_id: dev_id };
+
+	if (ioctl(sk, HCIGETDEVINFO, (void *) &di))
 		return 0;
+
 	return !bacmp((bdaddr_t *) arg, &di.bdaddr);
 }
 
@@ -1042,6 +1049,52 @@ int hci_read_local_version(int dd, struct hci_version *ver, int to)
 	return 0;
 }
 
+int hci_read_local_features(int dd, uint8_t *features, int to)
+{
+	read_local_features_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_INFO_PARAM;
+	rq.ocf    = OCF_READ_LOCAL_FEATURES;
+	rq.rparam = &rp;
+	rq.rlen   = READ_LOCAL_FEATURES_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	memcpy(features, rp.features, 8);
+	return 0;
+}
+
+int hci_read_bd_addr(int dd, bdaddr_t *bdaddr, int to)
+{
+	read_bd_addr_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_INFO_PARAM;
+	rq.ocf    = OCF_READ_BD_ADDR;
+	rq.rparam = &rp;
+	rq.rlen   = READ_BD_ADDR_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	bacpy(bdaddr, &rp.bdaddr);
+	return 0;
+}
+
 int hci_read_class_of_dev(int dd, uint8_t *cls, int to)
 {
 	read_class_of_dev_rp rp;
@@ -1619,3 +1672,44 @@ int hci_read_afh_map(int dd, uint16_t handle, uint8_t *mode, uint8_t *map, int t
 	memcpy(map, rp.map, 10);
 	return 0;
 }
+
+int hci_read_clock(int dd, uint16_t handle, uint8_t which, uint32_t *clock, uint16_t *accuracy, int to)
+{
+	read_clock_cp cp;
+	read_clock_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	cp.handle      = handle;
+	cp.which_clock = which;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_STATUS_PARAM;
+	rq.ocf    = OCF_READ_CLOCK;
+	rq.cparam = &cp;
+	rq.clen   = READ_CLOCK_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = READ_CLOCK_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*clock    = rp.clock;
+	*accuracy = rp.accuracy;
+	return 0;
+}
+
+int hci_local_name(int dd, int len, char *name, int to)
+{
+	return hci_read_local_name(dd, len, name, to);
+}
+
+int hci_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to)
+{
+	return hci_read_remote_name(dd, bdaddr, len, name, to);
+}
